Introduction
==============

 .. readme_inclusion_start

Python wrapper around the
`Fortran ciaaw library <https://milanskocic.github.io/ciaaw/index.html>`_.
The Fortran library does not need to be installed, the python wrapper embeds all needed fortran dependencies.
On linux, you might have to install `libgfortran` if it is not distributed by default with your linux distribution. 

.. readme_inclusion_end 


Installation
===================
See  ``INSTALL.txt``.

Dependencies
================

See ``requirements.txt``.


License information
===========================
See ``LICENSE.txt``.
